from lhcsmapi.gui.pc.fgc_pm_event_select.FgcPmEventSelectBaseModule import FgcPmEventSelectBaseModule
from lhcsmapi.gui.pc.fgc_pm_event_select.IpdFgcPmEventSelectBaseModule import IpdFgcPmEventSelectBaseModule
from lhcsmapi.gui.pc.fgc_pm_event_select.IpqFgcPmEventSelectBaseModule import IpqFgcPmEventSelectBaseModule
from lhcsmapi.gui.pc.fgc_pm_event_select.ItFgcPmEventSelectBaseModule import ItFgcPmEventSelectBaseModule
from lhcsmapi.gui.pc.fgc_pm_event_select.RbFgcPmEventSelectBaseModule import RbFgcPmEventSelectBaseModule
from lhcsmapi.gui.pc.fgc_pm_event_select.RqFgcPmEventSelectBaseModule import RqFgcPmEventSelectBaseModule
from lhcsmapi.gui.pc.fgc_pm_event_select.R600AFgcPmEventSelectBaseModule import \
    R600ARcdoFgcPmEventSelectBaseModule, R600ARcbxhvFgcPmEventSelectBaseModule


class FgcPmEventSelectBaseModuleFactory(object):
    """ Class builds objects for selecting a FGC PM event and performing actions depending on the circuit type.

    """

    @staticmethod
    def create(circuit_type: str):
        """ Method creating a FgcPmEventSelectBaseModule object for a FGC PM query of a given circuit type

        :param circuit_type: circuit type to initiate a FgcPmEventSelectBaseModule object
        :return: a FgcPmEventSelectBaseModule object for a given circuit type
        """

        if circuit_type == 'RB':
            return RbFgcPmEventSelectBaseModule(circuit_type)
        elif circuit_type == 'RQ':
            return RqFgcPmEventSelectBaseModule(circuit_type)
        elif circuit_type == 'IT':
            return ItFgcPmEventSelectBaseModule(circuit_type)
        elif circuit_type == 'IPD':
            return IpdFgcPmEventSelectBaseModule(circuit_type)
        elif circuit_type == 'IPQ':
            return IpqFgcPmEventSelectBaseModule(circuit_type)
        elif circuit_type == '600A_RCDO':
            return R600ARcdoFgcPmEventSelectBaseModule(circuit_type)
        elif circuit_type == '600A_RCBXHV':
            return R600ARcbxhvFgcPmEventSelectBaseModule(circuit_type)
        elif circuit_type in ['600A', '80-120A', '60A']:
            return FgcPmEventSelectBaseModule(circuit_type)
        else:
            raise ValueError('Circuit type {} not supported!'.format(circuit_type))
