from typing import List, Tuple

from IPython.display import display, Image

from lhcsmapi.Time import Time
from lhcsmapi.gui.pc.fgc_pm_event_select.FgcPmEventSelectBaseModule import FgcPmEventSelectBaseModule
from lhcsmapi.metadata.MappingMetadata import MappingMetadata


class IpdFgcPmEventSelectBaseModule(FgcPmEventSelectBaseModule):

    _repo_url = "https://gitlab.cern.ch/LHCData/lhc-sm-hwc/-/raw/master"
    _circuit_class_to_url = {'MBX': ("%s/figures/ipd/IPD_MBX_D1.png" % _repo_url),
                             'MBRC': ("%s/figures/ipd/IPD_MBRC_D2_MBRB_D4.png" % _repo_url),
                             'MBRS': ("%s/figures/ipd/IPD_MBRS_D3.png" % _repo_url),
                             'MBRB': ("%s/figures/ipd/IPD_MBRC_D2_MBRB_D4.png" % _repo_url)
                             }

    def display_qps_circuit_schematic(self, circuit_name: str) -> None:
        circuit_class = MappingMetadata.get_qps_schematic_naming('IPD', circuit_name)
        display(Image(url=self._circuit_class_to_url[circuit_class]))

    def convert_fgc_pm_events_to_options(self, fgc_pm_events: List[Tuple[str, int]]) -> List[str]:
        """ Method converting a list of source and timestamp tuples into a list of strings to be displayed

        :param fgc_pm_events: a list of FGC PM source and timestamp event tuples
        :return: list of strings with FGC PM source and timestamp
        """
        return [Time.to_string(el[1]) for el in fgc_pm_events]

