from typing import List, Tuple

from IPython.display import display, Image

from lhcsmapi.gui.pc.fgc_pm_event_select.FgcPmEventSelectBaseModule import FgcPmEventSelectBaseModule
from lhcsmapi.metadata.MappingMetadata import MappingMetadata


class IpqFgcPmEventSelectBaseModule(FgcPmEventSelectBaseModule):

    _repo_url = "https://gitlab.cern.ch/LHCData/lhc-sm-hwc/-/raw/master"
    _circuit_class_to_url = {'2MQM': ("%s/figures/ipq/2MQM_QPS.png" % _repo_url),
                             '2x2MQM': ("%s/figures/ipq/2x2MQM_QPS.png" % _repo_url),
                             '2MQML': ("%s/figures/ipq/2MQML_QPS.png" % _repo_url),
                             '2MQM+2MQML': ("%s/figures/ipq/2MQM_2MQML_QPS.png" % _repo_url),
                             '2MQM+2MQMC': ("%s/figures/ipq/2MQM_2MQMC_QPS.png" % _repo_url),
                             '2MQY': ("%s/figures/ipq/2MQY_QPS.png" % _repo_url),
                             '2x2MQY': ("%s/figures/ipq/2x2MQY_QPS.png" % _repo_url)
                             }

    def display_qps_circuit_schematic(self, circuit_name: str) -> None:
        circuit_class = MappingMetadata.get_qps_schematic_naming('IPQ', circuit_name)
        display(Image(url=self._circuit_class_to_url[circuit_class]))

    def convert_fgc_pm_events_to_options(self, fgc_pm_events: List[Tuple[str, int]]) -> List[str]:
        """ Method converting a list of source and timestamp tuples into a list of strings to be displayed

        :param fgc_pm_events: a list of FGC PM source and timestamp event tuples
        :return: list of strings with FGC PM source and timestamp
        """
        return [self.create_pm_circuit_name_timestamp_text(el) for el in fgc_pm_events]

