from lhcsmapi.gui.pc.fgc_pm_event_select.FgcPmEventSelectBaseModule import FgcPmEventSelectBaseModule


class R600ARcdoFgcPmEventSelectBaseModule(FgcPmEventSelectBaseModule):
    """ Specific class for search of 600A RCD-RCO FGC PM events by respective notebook browsers

    """

    def get_selected_circuit_name(self, fgc_pm_event):
        """ Method returning circuit name for a selected element in the list. The order is RCD followed by RCO.

        :param fgc_pm_event: a source and timestamp FGC PM tuples
        :return: a selected circuit name(s)
        """
        if len(fgc_pm_event) == 2:
            if 'RCD' in fgc_pm_event[0]:
                return fgc_pm_event[0], fgc_pm_event[0].replace('RCD', 'RCO')
            else:
                return fgc_pm_event[0].replace('RCO', 'RCD'), fgc_pm_event[0]
        else:
            if 'RCD' in fgc_pm_event[0]:
                return fgc_pm_event[0], fgc_pm_event[2]
            else:
                return fgc_pm_event[2], fgc_pm_event[0]

    def get_selected_timestamp(self, fgc_pm_event):
        """ Method returning a tuple of timestamps for a selected element in the list. The order is RCD followed by RCO.

        :param fgc_pm_event: a source and timestamp FGC PM tuples
        :return: a selected timestamp
        """
        if len(fgc_pm_event) == 2:
            if 'RCD' in fgc_pm_event[0]:
                return fgc_pm_event[1], float('nan')
            else:
                return float('nan'), fgc_pm_event[1]
        else:
            if 'RCD' in fgc_pm_event[0]:
                return fgc_pm_event[1], fgc_pm_event[3]
            else:
                return fgc_pm_event[3], fgc_pm_event[1]


class R600ARcbxhvFgcPmEventSelectBaseModule(FgcPmEventSelectBaseModule):
    """ Specific class for search of 600A RCBXH/V FGC PM events by respective notebook browsers

    """

    def get_selected_circuit_name(self, fgc_pm_event):
        """ Method returning circuit name for a selected element in the list. The order is RCBXH followed by RCBXV.

        :param fgc_pm_event: a source and timestamp FGC PM tuples
        :return: a selected circuit name(s)
        """
        if len(fgc_pm_event) == 2:
            if 'RCBXH' in fgc_pm_event[0]:
                return fgc_pm_event[0], fgc_pm_event[0].replace('RCBXH', 'RCBXV')
            else:
                return fgc_pm_event[0].replace('RCBXV', 'RCBXH'), fgc_pm_event[0]
        else:
            if 'RCBXH' in fgc_pm_event[0]:
                return fgc_pm_event[0], fgc_pm_event[2]
            else:
                return fgc_pm_event[2], fgc_pm_event[0]

    def get_selected_timestamp(self, fgc_pm_event):
        """ Method returning a tuple of timestamps for a selected element in the list. The order is RCBXH followed by
        RCBXV.

        :param fgc_pm_event: a source and timestamp FGC PM tuples
        :return: a selected timestamp
        """
        if len(fgc_pm_event) == 2:
            if 'RCBXH' in fgc_pm_event[0]:
                return fgc_pm_event[1], float('nan')
            else:
                return float('nan'), fgc_pm_event[1]
        else:
            if 'RCBXH' in fgc_pm_event[0]:
                return fgc_pm_event[1], fgc_pm_event[3]
            else:
                return fgc_pm_event[3], fgc_pm_event[1]
