from typing import List, Tuple, Union

from lhcsmapi.gui.pc.fgc_pm_event_select.FgcPmEventSelectBaseModule import FgcPmEventSelectBaseModule


class RqFgcPmEventSelectBaseModule(FgcPmEventSelectBaseModule):
    """ Specific class for search of RQ FGC PM events by respective notebook browsers

    """

    def convert_fgc_pm_events_to_options(self, fgc_pm_events: List[Tuple[str, int, str, int]]) -> List[str]:
        """ Method converting a list of source and timestamp tuples into a list of strings to be displayed

        :param fgc_pm_events: a list of FGC PM source and timestamp event tuples
        :return: list of strings with FGC PM source and timestamp
        """
        return [self.create_pm_circuit_name_timestamp_text(x) for x in fgc_pm_events]

    def get_selected_circuit_name(self, fgc_pm_event: List[Union[str, int]]) -> Tuple[str, str]:
        """ Method returning circuit name(s) of a selected event. In case of an event with two circuits,
        RQD is returned first (RQF is the second name).

        :param fgc_pm_event: a circuit name/timestamp tuple
        :return: a list of two circuit names associated with an FGC event.
        """
        if len(fgc_pm_event) == 2 and 'RQD' in fgc_pm_event[0]:
            return fgc_pm_event[0], fgc_pm_event[0].replace('RQD', 'RQF')
        if len(fgc_pm_event) == 2 and 'RQF' in fgc_pm_event[0]:
            return fgc_pm_event[0].replace('RQF', 'RQD'), fgc_pm_event[0]
        else:
            return fgc_pm_event[0], fgc_pm_event[2]

    def get_selected_timestamp(self, fgc_pm_event: List[Union[str, int]]) -> Tuple[float, float]:
        """ Method returning circuit name(s) of a selected event. In case of an event with two circuits,
        RQD is returned first (RQF is the second name).

        :param fgc_pm_event: a circuit name/timestamp tuple
        :return: a list of two circuit names associated with an FGC event. NaN if only one circuit is concerned.
        """
        if len(fgc_pm_event) == 2 and 'RQD' in fgc_pm_event[0]:
            return fgc_pm_event[1], float('nan')
        if len(fgc_pm_event) == 2 and 'RQF' in fgc_pm_event[0]:
            return float('nan'), fgc_pm_event[1]
        else:
            return fgc_pm_event[1], fgc_pm_event[3]
