import functools
from abc import ABC, abstractmethod

from ipywidgets import Button, Label, IntProgress, Layout, Box

from lhcsmapi.gui.BaseModule import BaseModule
from lhcsmapi.gui.pc.FgcBrowserAction import FgcBrowserAction


def convert_source_timestamp_to_circuit_name_timestamp(source_timestamp_df):
    output = []
    for index, row in source_timestamp_df.iterrows():
        pc_name = row['source']
        pc_name_split = pc_name.split('.')
        circuit_name = '%s.%s' % (pc_name_split[-2], pc_name_split[-1])
        output.append((circuit_name, row['timestamp']))
    return output


class FgcPmFindButtonBaseModule(BaseModule, ABC):

    def __init__(self, circuit_type):
        super().__init__()
        self.circuit_type = circuit_type

        # Widget
        self.find_btn = Button(
            description='Find FGC PM entries',
            tooltip='Click to find FGC PM entries between indicated dates.',
            button_style='',  # 'success', 'info', 'warning', 'danger' or ''
        )
        self.find_btn.on_click(functools.partial(FgcPmFindButtonBaseModule.handle_find_button_event, self=self))

        # # Text field
        self.lbl_search = Label(value="Click button to search for FGC PM entries within the specified period of time")

        # # Progress bar
        self.progress_search = IntProgress(value=0, min=0, step=1, bar_style='success',
                                           orientation='horizontal', layout=Layout(width='20%', visibility='hidden'))

        self.widget = [self.find_btn, self.lbl_search, self.progress_search]

    def handle_find_button_event(b, self):
        if self.mediator is not None:
            self.mediator.notify(self, FgcBrowserAction.FIND_BUTTON_CLICKED)

    @abstractmethod
    def find_fgc_pm_events_with_qps(self, start_time, end_time, circuit_name):
        """ Method finding FGC PM entries with QPS for a given time range and circuit name

        :param start_time: start time for the query
        :param end_time: end time for the query
        :param circuit_name: circuit name
        :return: a list of FGC source and timestamp tuples
        """
        pass