from typing import List, Tuple

from lhcsmapi.gui.pc.fgc_pm_find_button.FgcPmFindButtonBaseModule import FgcPmFindButtonBaseModule
from lhcsmapi.metadata.SignalMetadata import SignalMetadata
from lhcsmapi.pyedsl.QueryBuilder import QueryBuilder


class IpdFgcPmFindButtonBaseModule(FgcPmFindButtonBaseModule):
    """ A class with methods to search for IPD FGC PM events to fill-in a search field in the FGC PM search module.

    """

    def find_fgc_pm_events_with_qps(self, start_time, end_time, circuit_name: str) -> List[Tuple[str, int]]:
        """ Method finding FGC PM entries with QPS for a given time range and circuit name

        :param start_time: start time for the query
        :param end_time: end time for the query
        :param circuit_name: circuit name
        :return: a list of FGC source and timestamp tuples
        """
        self.lbl_search.value = 'Querying PM for FGC events'
        self.progress_search.layout.visibility = 'visible'
        self.progress_search.max = 1
        self.progress_search.description = ''

        output = query_pm_convert_pc_to_circuit_name(start_time, end_time, circuit_name)

        self.lbl_search.value = 'Query completed'
        self.progress_search.layout.visibility = 'visible'
        self.progress_search.value = 1
        self.progress_search.description = ''

        return output


def query_pm_convert_pc_to_circuit_name(start_time, end_time, circuit_name: str) -> List[Tuple[str, int]]:
    """ Method querying FGC PM source and timestamp tuple and taking only those corresponding to the given circuits

    :param start_time: start time for a query
    :param end_time: end time for a query
    :param circuit_name: circuit name
    :return: a list of PM source and timestamp tuples corresponding to circuit names
    """
    circuit_type = SignalMetadata.get_circuit_type_for_circuit_name(circuit_name)

    # Query PM for the specified period of tim
    source_timestamp_df = QueryBuilder().with_pm() \
        .with_duration(t_start=start_time, t_end=end_time) \
        .with_circuit_type(circuit_type) \
        .with_metadata(circuit_name=circuit_name, system='PC', source='*') \
        .event_query().drop_duplicates('timestamp').df

    # Use circuit name instead of power converter name
    circuit_name_timestamp_fgc_with_qps = [(circuit_name, el) for el in source_timestamp_df['timestamp'].values]
    return circuit_name_timestamp_fgc_with_qps
