from abc import ABC, abstractmethod
from typing import List

import pandas as pd


class SignalDbQuery(ABC):
    """ An abstract class for encapsulating the read methods of logging databases (PM and NXCALS)
    """

    def __init__(self, api=''):
        """ Constructor setting an API name (PM or NXCALS)

        :param api: API name
        """
        self.api = api

    @abstractmethod
    def read(self) -> List[pd.DataFrame]:
        """ An abstract read method returning a list of DataFrames

        :return: List of DataFrames with queried signals
        """
        pass
