from unittest import TestCase

from lhcsmapi.gui.pc.fgc_pm_event_select.FgcPmEventSelectBaseModuleFactory import FgcPmEventSelectBaseModuleFactory


class TestFgcPmEventSelectBaseModule(TestCase):

    def test_create_pm_circuit_name_timestamp_text(self):
        # arrange
        fgc_pm_event = ('RCS.A45B1', 1611941460800000000)
        fgc_pm_module = FgcPmEventSelectBaseModuleFactory.create(circuit_type='600A')

        # act
        timestamp_text_act = fgc_pm_module.create_pm_circuit_name_timestamp_text(fgc_pm_event)

        # assert
        timestamp_text_ref = 'RCS.A45B1: 2021-01-29 18:31:00.800000+01:00'
        self.assertEqual(timestamp_text_ref, timestamp_text_act)

    def test_convert_fgc_pm_events_to_options_600A(self):
        # arrange
        fgc_pm_events = [('RCS.A45B1', 1611941460800000000),
                         ('RCS.A45B1', 1611943957300000000),
                         ('RCS.A45B2', 1611901122500000000),
                         ('RCS.A45B2', 1611946760300000000),
                         ('RCS.A45B2', 1611949258300000000)]
        fgc_pm_module = FgcPmEventSelectBaseModuleFactory.create(circuit_type='600A')

        # act
        options_act = fgc_pm_module.convert_fgc_pm_events_to_options(fgc_pm_events)

        # assert
        options_ref = ['RCS.A45B1: 2021-01-29 18:31:00.800000+01:00',
                       'RCS.A45B1: 2021-01-29 19:12:37.300000+01:00',
                       'RCS.A45B2: 2021-01-29 07:18:42.500000+01:00',
                       'RCS.A45B2: 2021-01-29 19:59:20.300000+01:00',
                       'RCS.A45B2: 2021-01-29 20:40:58.300000+01:00']
        self.assertListEqual(options_ref, options_act)

    def test_get_selected_circuit_name_600A(self):
        # arrange
        fgc_pm_event = 'RCS.A45B1', 1611941460800000000
        fgc_pm_module = FgcPmEventSelectBaseModuleFactory.create(circuit_type='600A')

        # act
        circuit_name_act = fgc_pm_module.get_selected_circuit_name(fgc_pm_event)

        # assert
        circuit_name_ref = 'RCS.A45B1'

        self.assertEqual(circuit_name_ref, circuit_name_act)

    def test_get_selected_timestamp_600A(self):
        # arrange
        fgc_pm_event = 'RCS.A45B1', 1611941460800000000
        fgc_pm_module = FgcPmEventSelectBaseModuleFactory.create(circuit_type='600A')

        # act
        timestamp_act = fgc_pm_module.get_selected_timestamp(fgc_pm_event)

        # assert
        timestamp_ref = 1611941460800000000

        self.assertEqual(timestamp_ref, timestamp_act)

    def test_convert_fgc_pm_events_to_options_80_120A(self):
        # arrange
        fgc_pm_events = [('RCBCHS5.L8B1', 1611948186420000000),
                         ('RCBCHS5.L8B1', 1611948486580000000),
                         ('RCBCHS5.L8B1', 1611948635420000000),
                         ('RCBCHS5.L8B2', 1611948814920000000),
                         ('RCBCHS5.L8B2', 1611949111580000000),
                         ('RCBCHS5.L8B2', 1611949260420000000)]
        fgc_pm_module = FgcPmEventSelectBaseModuleFactory.create(circuit_type='80-120A')

        # act
        options_act = fgc_pm_module.convert_fgc_pm_events_to_options(fgc_pm_events)

        # assert
        options_ref = ['RCBCHS5.L8B1: 2021-01-29 20:23:06.420000+01:00', 
                       'RCBCHS5.L8B1: 2021-01-29 20:28:06.580000+01:00', 
                       'RCBCHS5.L8B1: 2021-01-29 20:30:35.420000+01:00', 
                       'RCBCHS5.L8B2: 2021-01-29 20:33:34.920000+01:00', 
                       'RCBCHS5.L8B2: 2021-01-29 20:38:31.580000+01:00', 
                       'RCBCHS5.L8B2: 2021-01-29 20:41:00.420000+01:00']
        self.assertListEqual(options_ref, options_act)

    def test_get_selected_circuit_name_80_120A(self):
        # arrange
        fgc_pm_event = 'RCBCHS5.L8B1', 1611948186420000000
        fgc_pm_module = FgcPmEventSelectBaseModuleFactory.create(circuit_type='80-120A')

        # act
        circuit_name_act = fgc_pm_module.get_selected_circuit_name(fgc_pm_event)

        # assert
        circuit_name_ref = 'RCBCHS5.L8B1'

        self.assertEqual(circuit_name_ref, circuit_name_act)

    def test_get_selected_timestamp_80_120A(self):
        # arrange
        fgc_pm_event = 'RCBCHS5.L8B1', 1611948186420000000
        fgc_pm_module = FgcPmEventSelectBaseModuleFactory.create(circuit_type='80-120A')

        # act
        timestamp_act = fgc_pm_module.get_selected_timestamp(fgc_pm_event)

        # assert
        timestamp_ref = 1611948186420000000

        self.assertEqual(timestamp_ref, timestamp_act)

    def test_convert_fgc_pm_events_to_options_60A(self):
        # arrange
        fgc_pm_events = [('RCBH11.L8B1', 1611944437100000000),
                         ('RCBH11.L8B1', 1611945091600000000),
                         ('RCBH11.R7B1', 1611944436620000000),
                         ('RCBH11.R7B1', 1611945091620000000)]
        fgc_pm_module = FgcPmEventSelectBaseModuleFactory.create(circuit_type='60A')

        # act
        options_act = fgc_pm_module.convert_fgc_pm_events_to_options(fgc_pm_events)

        # assert
        options_ref = ['RCBH11.L8B1: 2021-01-29 19:20:37.100000+01:00',
                       'RCBH11.L8B1: 2021-01-29 19:31:31.600000+01:00',
                       'RCBH11.R7B1: 2021-01-29 19:20:36.620000+01:00',
                       'RCBH11.R7B1: 2021-01-29 19:31:31.620000+01:00']
        self.assertListEqual(options_ref, options_act)

    def test_get_selected_circuit_name_60A(self):
        # arrange
        fgc_pm_event = 'RCBH11.L8B1', 1611944437100000000
        fgc_pm_module = FgcPmEventSelectBaseModuleFactory.create(circuit_type='60A')

        # act
        circuit_name_act = fgc_pm_module.get_selected_circuit_name(fgc_pm_event)

        # assert
        circuit_name_ref = 'RCBH11.L8B1'

        self.assertEqual(circuit_name_ref, circuit_name_act)

    def test_get_selected_timestamp_60A(self):
        # arrange
        fgc_pm_event = 'RCBH11.L8B1', 1611944437100000000
        fgc_pm_module = FgcPmEventSelectBaseModuleFactory.create(circuit_type='60A')

        # act
        timestamp_act = fgc_pm_module.get_selected_timestamp(fgc_pm_event)

        # assert
        timestamp_ref = 1611944437100000000

        self.assertEqual(timestamp_ref, timestamp_act)