from io import StringIO
from unittest import TestCase
from unittest.mock import patch

from lhcsmapi.gui.pc.fgc_pm_event_select.FgcPmEventSelectBaseModuleFactory import FgcPmEventSelectBaseModuleFactory


class TestIpqFgcPmEventSelectBaseModule(TestCase):

    def test_display_qps_circuit_schematic(self):
        # arrange
        ipq_fgc_pm_module = FgcPmEventSelectBaseModuleFactory.create('IPQ')

        # act
        with patch('sys.stdout', new=StringIO()) as fake_out:
            ipq_fgc_pm_module.display_qps_circuit_schematic('RQ4.L2')

        # assert
        expected_out = '<IPython.core.display.Image object>'
        self.assertEqual(fake_out.getvalue().strip(), expected_out)

    def test_convert_fgc_pm_events_to_options(self):
        # arrange
        fgc_pm_events = [('RQ4.L2', 1544455364980000000),
                         ('RQ4.L2', 1544465633760000000),
                         ('RQ4.L2', 1544476819860000000)]
        ipq_fgc_pm_module = FgcPmEventSelectBaseModuleFactory.create('IPQ')

        # act
        options_act = ipq_fgc_pm_module.convert_fgc_pm_events_to_options(fgc_pm_events)

        # assert
        options_ref = ['RQ4.L2: 2018-12-10 16:22:44.980000+01:00',
                       'RQ4.L2: 2018-12-10 19:13:53.760000+01:00',
                       'RQ4.L2: 2018-12-10 22:20:19.860000+01:00']
        self.assertListEqual(options_ref, options_act)
