from unittest import TestCase

from lhcsmapi.gui.pc.fgc_pm_event_select.FgcPmEventSelectBaseModuleFactory import FgcPmEventSelectBaseModuleFactory


class TestR600ARcbxhvFgcPmEventSelectBaseModule(TestCase):
    def test_get_selected_circuit_name(self):
        # arrange
        fgc_pm_event = ('RCBXV1.R1', 1493219269220000000, 'RCBXH1.R1', 1493219269240000000)
        rq_fgc_pm_module = FgcPmEventSelectBaseModuleFactory.create(circuit_type='600A_RCBXHV')

        # act
        circuit_names_act = rq_fgc_pm_module.get_selected_circuit_name(fgc_pm_event)

        # assert
        circuit_names_ref = 'RCBXH1.R1', 'RCBXV1.R1'

        self.assertEqual(circuit_names_ref, circuit_names_act)

    def test_get_selected_timestamp(self):
        # arrange
        fgc_pm_event = ('RCBXV1.R1', 1493219269220000000, 'RCBXH1.R1', 1493219269240000000)
        rq_fgc_pm_module = FgcPmEventSelectBaseModuleFactory.create(circuit_type='600A_RCBXHV')

        # act
        circuit_names_act = rq_fgc_pm_module.get_selected_timestamp(fgc_pm_event)

        # assert
        circuit_names_ref = 1493219269240000000, 1493219269220000000

        self.assertEqual(circuit_names_ref, circuit_names_act)


class TestR600ARcdoFgcPmEventSelectBaseModule(TestCase):
    def test_get_selected_circuit_name(self):
        # arrange
        fgc_pm_event = ('RCO.A81B2', 1521459746200000000, 'RCD.A81B2', 1521459746260000000)
        rq_fgc_pm_module = FgcPmEventSelectBaseModuleFactory.create(circuit_type='600A_RCDO')

        # act
        circuit_names_act = rq_fgc_pm_module.get_selected_circuit_name(fgc_pm_event)

        # assert
        circuit_names_ref = 'RCD.A81B2', 'RCO.A81B2'

        self.assertEqual(circuit_names_ref, circuit_names_act)

    def test_get_selected_timestamp(self):
        # arrange
        fgc_pm_event = ('RCO.A81B2', 1521459746200000000, 'RCD.A81B2', 1521459746260000000)
        rq_fgc_pm_module = FgcPmEventSelectBaseModuleFactory.create(circuit_type='600A_RCDO')

        # act
        circuit_names_act = rq_fgc_pm_module.get_selected_timestamp(fgc_pm_event)

        # assert
        circuit_names_ref = 1521459746260000000, 1521459746200000000

        self.assertEqual(circuit_names_ref, circuit_names_act)
