from unittest import TestCase

from lhcsmapi.gui.pc.fgc_pm_event_select.FgcPmEventSelectBaseModuleFactory import FgcPmEventSelectBaseModuleFactory


class TestRqFgcPmEventSelectBaseModule(TestCase):
    def test_convert_fgc_pm_events_to_options(self):
        # arrange
        fgc_pm_events = [('RQD.A12', 1544456704520000000, 'RQF.A12', 1544456704520000000),
                         ('RQD.A12', 1544466193140000000, 'RQF.A12', 1544466193140000000),
                         ('RQD.A12', 1544550419780000000, 'RQF.A12', 1544550419780000000),
                         ('RQD.A12', 1544622149620000000, 'RQF.A12', 1544622149620000000)]
        rq_fgc_pm_module = FgcPmEventSelectBaseModuleFactory.create(circuit_type='RQ')

        # act
        options_act = rq_fgc_pm_module.convert_fgc_pm_events_to_options(fgc_pm_events)

        # assert
        options_ref = ['RQD.A12: 2018-12-10 16:45:04.520000+01:00; RQF.A12: 2018-12-10 16:45:04.520000+01:00',
                       'RQD.A12: 2018-12-10 19:23:13.140000+01:00; RQF.A12: 2018-12-10 19:23:13.140000+01:00',
                       'RQD.A12: 2018-12-11 18:46:59.780000+01:00; RQF.A12: 2018-12-11 18:46:59.780000+01:00',
                       'RQD.A12: 2018-12-12 14:42:29.620000+01:00; RQF.A12: 2018-12-12 14:42:29.620000+01:00']

        self.assertListEqual(options_ref, options_act)

    def test_get_selected_circuit_name_rqd_rqf(self):
        # arrange
        fgc_pm_event = ['RQD.A12', 1544456704520000000, 'RQF.A12', 1544456704520000000]
        rq_fgc_pm_module = FgcPmEventSelectBaseModuleFactory.create(circuit_type='RQ')

        # act
        circuit_name = rq_fgc_pm_module.get_selected_circuit_name(fgc_pm_event)

        # assert
        circuit_name_ref = ['RQD.A12', 'RQF.A12']
        self.assertListEqual(circuit_name_ref, list(circuit_name))

    def test_get_selected_circuit_name_rqd(self):
        # arrange
        fgc_pm_event = ['RQD.A12', 1544456704520000000]
        rq_fgc_pm_module = FgcPmEventSelectBaseModuleFactory.create(circuit_type='RQ')

        # act
        circuit_name = rq_fgc_pm_module.get_selected_circuit_name(fgc_pm_event)

        # assert
        circuit_name_ref = ['RQD.A12', 'RQF.A12']
        self.assertListEqual(circuit_name_ref, list(circuit_name))

    def test_get_selected_circuit_name_rqf(self):
        # arrange
        fgc_pm_event = ['RQF.A12', 1544456704520000000]
        rq_fgc_pm_module = FgcPmEventSelectBaseModuleFactory.create(circuit_type='RQ')

        # act
        circuit_name = rq_fgc_pm_module.get_selected_circuit_name(fgc_pm_event)

        # assert
        circuit_name_ref = ['RQD.A12', 'RQF.A12']
        self.assertListEqual(circuit_name_ref, list(circuit_name))

    def test_get_selected_timestamp_rqd_rqf(self):
        # arrange
        fgc_pm_event = ['RQD.A12', 1544456704520000000, 'RQF.A12', 1544456704520000000]
        rq_fgc_pm_module = FgcPmEventSelectBaseModuleFactory.create(circuit_type='RQ')

        # act
        circuit_name = rq_fgc_pm_module.get_selected_timestamp(fgc_pm_event)

        # assert
        circuit_name_ref = [1544456704520000000, 1544456704520000000]
        self.assertListEqual(circuit_name_ref, list(circuit_name))

    def test_get_selected_timestamp_rqd(self):
        # arrange
        fgc_pm_event = ['RQD.A12', 1544456704520000000]
        rq_fgc_pm_module = FgcPmEventSelectBaseModuleFactory.create(circuit_type='RQ')

        # act
        circuit_name = rq_fgc_pm_module.get_selected_timestamp(fgc_pm_event)

        # assert
        circuit_name_ref = [1544456704520000000, float('nan')]
        self.assertEqual(circuit_name_ref[0], list(circuit_name)[0])

    def test_get_selected_timestamp_rqf(self):
        # arrange
        fgc_pm_event = ['RQF.A12', 1544456704520000000]
        rq_fgc_pm_module = FgcPmEventSelectBaseModuleFactory.create(circuit_type='RQ')

        # act
        circuit_name = rq_fgc_pm_module.get_selected_timestamp(fgc_pm_event)

        # assert
        circuit_name_ref = [float('nan'), 1544456704520000000]
        self.assertEqual(circuit_name_ref[1], list(circuit_name)[1])
