import warnings
import unittest
from unittest import mock

from lhcsmapi.pyedsl.dbsignal.nxcals.NxcalsDevicePropertySignalDbQuery import NxcalsDevicePropertySignalDbQuery
from lhcsmapi.pyedsl.dbsignal.nxcals.NxcalsVariableSignalDbQuery import NxcalsVariableSignalDbQuery


class TestNxcalsDbSignal(unittest.TestCase):

    def test_init_exception(self):
        # arrange

        # act
        # assert
        with self.assertRaises(Exception) as context:
            NxcalsVariableSignalDbQuery(t_start=1, t_end=1.5, nxcals_system='WINCCOA', signals=["U_RES"])

        self.assertEqual('You have to provide an instance of spark connector via the spark keyword',
                         str(context.exception))

    def test_read_system_warning(self):
        # arrange
        spark_mock = mock.Mock()

        # act
        # assert
        with warnings.catch_warnings(record=True) as w:
            NxcalsVariableSignalDbQuery(t_start=1, t_end=1.5, nxcals_system='WINCCOA',
                                        signals=["U_RES"], spark=spark_mock).read()

        self.assertEqual("name 'VariableQuery' is not defined", str(w[0].message))
        self.assertEqual("""NXCALS query failed with the parameters, nxcals_system: WINCCOA, t_start: 1, t_end: 1.5, 
                        signals: ['U_RES']

                        List of empty signals returned.
                        ___________________________________________________________________________________
                        You can reproduce the error using the raw NXCALS API:

                        from cern.nxcals.pyquery.builders import *
            
                        variable_builder = VariableQuery.builder(spark) \\
                            .system(WINCCOA) \\
                            .startTime(1).endTime(1.5)

                        for signal in ['U_RES']:
                            variable_builder = variable_builder.variable(signal)
            
                        multisignal_df = variable_builder.buildDataset().select(
                            ['nxcals_timestamp', 'nxcals_value', 'nxcals_variable_name']).dropna().toPandas()
            
                        multisignal_df.set_index(multisignal_df['nxcals_timestamp'], inplace=True)
                        multisignal_df.drop(columns='nxcals_timestamp', inplace=True)
                        multisignal_df.dropna(inplace=True)
                        multisignal_df.sort_index(inplace=True)
            
                        multisignal_dct = dict(tuple(multisignal_df.groupby('nxcals_variable_name')))
                        signal_dfs = []
                        for signal in ['U_RES']:
                            signal_df = multisignal_dct.get(signal, pd.DataFrame(columns=[signal]))
                            signal_df.sort_index(inplace=True)
                            signal_df.drop(columns='nxcals_variable_name', inplace=True)
                            signal_df.rename(columns=dict('nxcals_value': signal), inplace=True)
                            signal_dfs.append(signal_df)
                """, str(w[1].message))

    def test_read_system_device_property_warning(self):
        # arrange
        spark_mock = mock.Mock()

        # act
        # assert
        with warnings.catch_warnings(record=True) as w:
            NxcalsDevicePropertySignalDbQuery(nxcals_system='CMW', nxcals_devices=['RPTE.UA43.RB.A34'],
                                              nxcals_property='SUB', signal="I_MEAS",
                                              t_start=1, t_end=1.5, spark=spark_mock).read()
        self.assertEqual("name 'DevicePropertyQuery' is not defined", str(w[0].message))
        self.assertEqual("""NXCALS query failed with the parameters, nxcals_system: CMW, t_start: 1, t_end: 1.5, 
                        nxcals_devices: ['RPTE.UA43.RB.A34'], nxcals_property: SUB, signal: I_MEAS

                        List of empty signals returned.
                        ___________________________________________________________________________________
                        You can reproduce the error using the raw NXCALS API:

                        from cern.nxcals.pyquery.builders import *
                        
                        device_property_builder = DevicePropertyQuery.builder(spark) \\
                            .system(CMW) \\
                            .startTime(1) \\
                            .endTime(1.5) \\

                        # Populate builder
                        for nxcals_device in ['RPTE.UA43.RB.A34']:
                            device_property_builder = device_property_builder.entity() \\
                                .device(nxcals_device).property(SUB)
            
                        # Execute query
                        multisignal_df = device_property_builder.buildDataset().select(
                            ['acqStamp', I_MEAS, 'device']).dropna().toPandas()
                        multisignal_df.set_index(multisignal_df['acqStamp'], inplace=True)
                        multisignal_df.drop(columns='acqStamp', inplace=True)
                        
                        # Extract signals in the order of input devices
                        multisignal_dct = dict(tuple(multisignal_df.groupby('device')))
                        signal_dfs = []
                        for nxcals_device in ['RPTE.UA43.RB.A34']:
                            signal_df = multisignal_dct.get(nxcals_device, pd.DataFrame(columns=[I_MEAS]))
                            signal_df.sort_index(inplace=True)
                            signal_df.drop(columns='device')
                            signal_dfs.append(signal_df)
                        """, str(w[1].message))
